@@ -1,15 +1,12 @@
 #!/usr/bin/env perl
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Modules.
-use Error::Pure::PrintVar qw(err);
+use Error::Pure::ErrorList qw(err);
 
 # Error.
 err '1', '2', '3';
 
 # Output:
-# 1
-# 2: 3
\ No newline at end of file
+# #Error [example2.pl:9] 1
\ No newline at end of file
